---
title: <span class="badge object-type-scalar"></span> KiloAmpereHour
---
# <span class="badge object-type-scalar"></span> KiloAmpereHour

Energy: Kiloampere-hour (kAh)

## Definition

```python
# Energy: Kiloampere-hour (kAh)
KiloAmpereHour: typing.Literal["kamph"] = "kamph"
```
